@@ -1,7 +1,7 @@
 /* This example code is placed in the public domain. */
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -18,8 +18,8 @@ void check_alert(gnutls_session_t session, int ret)
 {
 	int last_alert;
 
-	if (ret == GNUTLS_E_WARNING_ALERT_RECEIVED
-	    || ret == GNUTLS_E_FATAL_ALERT_RECEIVED) {
+	if (ret == GNUTLS_E_WARNING_ALERT_RECEIVED ||
+	    ret == GNUTLS_E_FATAL_ALERT_RECEIVED) {
 		last_alert = gnutls_alert_get(session);
 
 		/* The check for renegotiation is only useful if we are 
